@@ -2,6 +2,7 @@ from typing import Union
 
 from bigquery_frame.dataframe import cols_to_str, Column
 from bigquery_frame.functions import __str_to_col
+from bigquery_frame import functions as f
 
 
 def when(condition: Column, value: Column) -> Column:
@@ -17,9 +18,9 @@ def when(condition: Column, value: Column) -> Column:
 
 def hash(*cols: Union[str, Column]) -> Column:
     cols = __str_to_col(cols)
-    return Column(f"FARM_FINGERPRINT(TO_JSON_STRING(STRUCT({cols_to_str(cols)})))")
+    return f.expr(f"FARM_FINGERPRINT(TO_JSON_STRING(STRUCT({cols_to_str(cols)})))")
 
 
 def sort_array(col: Union[str, Column]) -> Column:
     col = __str_to_col(col)
-    return Column(f"ARRAY(SELECT x FROM UNNEST({col}) AS x ORDER BY x)")
+    return f.expr(f"ARRAY(SELECT x FROM UNNEST({col}) AS x ORDER BY x)")
